@@ -1,10 +1,11 @@
-from django.test import TestCase
+from django.test import TestCase, override_settings
 from django.urls import reverse
 from django.contrib.messages import get_messages
 from django.db.models import Sum
 
 from allianceauth.tests.auth_utils import AuthUtils
 from allianceauth.authentication.models import CharacterOwnership
+from allianceauth.eveonline.models import EveCharacter
 
 from ..models import Rotation, Entry, EntryCharacter, EntryRole
 
@@ -58,7 +59,7 @@ class TestRotationView(TestCase):
         entry = Entry.objects.create(
             rotation=cls.rotation,
             created_by=cls.testuser,
-            estimated_total=1_000_000_000.0
+            estimated_total=1_000_000_000
         )
 
         role = EntryRole.objects.create(
@@ -99,7 +100,7 @@ class TestRotationView(TestCase):
         self.client.force_login(self.testuser)
 
         form_data = {
-            'sales_value': '900000000',
+            'sales_value': '900,000,000',
         }
 
         response = self.client.post(reverse('allianceauth_pve:rotation_view', args=[self.rotation.pk]), form_data)
@@ -135,7 +136,7 @@ class TestRotationView(TestCase):
         self.client.force_login(self.testuser)
 
         form_data = {
-            'sales_value': '900000000',
+            'sales_value': '900,000,000',
         }
 
         response = self.client.post(reverse('allianceauth_pve:rotation_view', args=[self.rotation.pk]), form_data)
@@ -252,6 +253,98 @@ class TestGetAvaiableRatters(TestCase):
         self.assertEqual(response.status_code, 200)
         self.assertJSONEqual(response.content, {'result': []})
 
+    @override_settings(PVE_ONLY_MAINS=True)
+    def test_alt_name_only_main(self):
+        self.client.force_login(self.testuser)
+
+        testcharacter2bis = EveCharacter.objects.create(
+            character_id=1510588747,
+            character_name='aauth_testchar3bis',
+            corporation_id=int(2345),
+            corporation_name='',
+            corporation_ticker='',
+            alliance_id=None,
+            alliance_name='',
+            faction_id=None,
+            faction_name=''
+        )
+        CharacterOwnership.objects.create(character=testcharacter2bis, user=self.testuser2, owner_hash='aa2bis')
+
+        response = self.client.get(reverse('allianceauth_pve:search_ratters', args=['bis']))
+
+        self.assertEqual(response.status_code, 200)
+        self.assertJSONEqual(
+            response.content,
+            {
+                'result': [
+                    {
+                        'character_id': self.testcharacter2.pk,
+                        'character_name': self.testcharacter2.character_name,
+                        'profile_pic': self.testcharacter2.portrait_url_32,
+                        'user_id': self.testuser2.pk,
+                        'user_main_character_name': self.testcharacter2.character_name,
+                        'user_pic': self.testcharacter2.portrait_url_32,
+                    }
+                ]
+            }
+        )
+
+    def test_alt_name(self):
+        self.client.force_login(self.testuser)
+
+        testcharacter2bis = EveCharacter.objects.create(
+            character_id=1510588747,
+            character_name='aauth_testchar3bis',
+            corporation_id=int(2345),
+            corporation_name='',
+            corporation_ticker='',
+            alliance_id=None,
+            alliance_name='',
+            faction_id=None,
+            faction_name=''
+        )
+        CharacterOwnership.objects.create(character=testcharacter2bis, user=self.testuser2, owner_hash='aa2bis')
+
+        testcharacter2tris = EveCharacter.objects.create(
+            character_id=391334192,
+            character_name='aauth_testchar3tris',
+            corporation_id=int(2345),
+            corporation_name='',
+            corporation_ticker='',
+            alliance_id=None,
+            alliance_name='',
+            faction_id=None,
+            faction_name=''
+        )
+        CharacterOwnership.objects.create(character=testcharacter2tris, user=self.testuser2, owner_hash='aa2tris')
+
+        response = self.client.get(reverse('allianceauth_pve:search_ratters', args=['bis']))
+
+        self.assertEqual(response.status_code, 200)
+        self.assertJSONEqual(
+            response.content,
+            {
+                'result': [
+                    {
+                        'character_id': self.testcharacter2.pk,
+                        'character_name': self.testcharacter2.character_name,
+                        'profile_pic': self.testcharacter2.portrait_url_32,
+                        'user_id': self.testuser2.pk,
+                        'user_main_character_name': self.testcharacter2.character_name,
+                        'user_pic': self.testcharacter2.portrait_url_32,
+                    },
+                    {
+                        'character_id': testcharacter2bis.pk,
+                        'character_name': testcharacter2bis.character_name,
+                        'profile_pic': testcharacter2bis.portrait_url_32,
+                        'user_id': self.testuser2.pk,
+                        'user_main_character_name': self.testcharacter2.character_name,
+                        'user_pic': self.testcharacter2.portrait_url_32,
+                    }
+                ]
+            }
+        )
+
 
 class TestAddEntryView(TestCase):
 
@@ -276,7 +369,7 @@ class TestAddEntryView(TestCase):
         cls.entry: Entry = Entry.objects.create(
             rotation=cls.rotation,
             created_by=cls.testuser,
-            estimated_total=1_000_000_000.0
+            estimated_total=1_000_000_000
         )
 
         cls.role: EntryRole = EntryRole.objects.create(
@@ -351,105 +444,42 @@ class TestAddEntryView(TestCase):
         self.assertEqual(response.status_code, 200)
         self.assertTemplateUsed(response, 'allianceauth_pve/entry_form.html')
 
-    def test_post_invalid_role_form(self):
+    def test_invalid_form(self):
         self.client.force_login(self.testuser)
 
         form_data = {
-            'roles-TOTAL_FORMS': '1',
-            'roles-INITIAL_FORMS': '1',
-            'roles-MIN_NUM_FORMS': '1',
-            'roles-MAX_NUM_FORMS': '1000',
-            'roles-0-name': 'Krab',
-            'roles-0-value': '-1',
-            'estimated_total': '553400000',
-            'form-TOTAL_FORMS': '1',
-            'form-INITIAL_FORMS': '0',
-            'form-MIN_NUM_FORMS': '0',
-            'form-MAX_NUM_FORMS': '1000',
-            'form-0-user': self.testuser.pk,
-            'form-0-character': self.testcharacter.pk,
-            'form-0-role': 'Krab',
-            'form-0-site_count': '1'
-        }
-
-        response = self.client.post(reverse('allianceauth_pve:new_entry', args=[self.rotation.pk]), form_data)
-
-        self.assertEqual(response.status_code, 200)
-        self.assertTemplateUsed(response, 'allianceauth_pve/entry_form.html')
-
-    def test_post_invalid_entry_form(self):
-        self.client.force_login(self.testuser)
-
-        form_data = {
-            'roles-TOTAL_FORMS': '1',
+            'roles-TOTAL_FORMS': '2',
             'roles-INITIAL_FORMS': '1',
             'roles-MIN_NUM_FORMS': '1',
             'roles-MAX_NUM_FORMS': '1000',
             'roles-0-name': 'Krab',
             'roles-0-value': '1',
-            'estimated_total': '0',
-            'form-TOTAL_FORMS': '1',
+            'roles-1-name': 'Krab2',
+            'roles-1-value': '0',
+            'estimated_total': '1660200000',
+            'form-TOTAL_FORMS': '2',
             'form-INITIAL_FORMS': '0',
             'form-MIN_NUM_FORMS': '0',
             'form-MAX_NUM_FORMS': '1000',
             'form-0-user': self.testuser.pk,
             'form-0-character': self.testcharacter.pk,
-            'form-0-role': 'Krab',
-            'form-0-site_count': '1'
+            'form-0-role': 'Krab2',
+            'form-0-helped_setup': 'on',
+            'form-0-site_count': '2',
+            'form-1-user': self.testuser2.pk,
+            'form-1-character': self.testcharacter2.pk,
+            'form-1-role': 'Krab',
+            'form-1-site_count': '0'
         }
 
         response = self.client.post(reverse('allianceauth_pve:new_entry', args=[self.rotation.pk]), form_data)
 
         self.assertEqual(response.status_code, 200)
-        self.assertTemplateUsed(response, 'allianceauth_pve/entry_form.html')
 
-    def test_post_invalid_share_form(self):
-        self.client.force_login(self.testuser)
+        messages = list(get_messages(response.wsgi_request))
 
-        form_data = {
-            'roles-TOTAL_FORMS': '1',
-            'roles-INITIAL_FORMS': '1',
-            'roles-MIN_NUM_FORMS': '1',
-            'roles-MAX_NUM_FORMS': '1000',
-            'roles-0-name': 'Krab',
-            'roles-0-value': '1',
-            'estimated_total': '10',
-            'form-TOTAL_FORMS': '1',
-            'form-INITIAL_FORMS': '0',
-            'form-MIN_NUM_FORMS': '0',
-            'form-MAX_NUM_FORMS': '1000',
-            'form-0-user': self.testuser.pk,
-            'form-0-character': self.testcharacter.pk,
-            'form-0-role': 'Krab',
-            'form-0-site_count': '-1'
-        }
-
-        response = self.client.post(reverse('allianceauth_pve:new_entry', args=[self.rotation.pk]), form_data)
-
-        self.assertEqual(response.status_code, 200)
-        self.assertTemplateUsed(response, 'allianceauth_pve/entry_form.html')
-
-    def test_post_no_shares(self):
-        self.client.force_login(self.testuser)
-
-        form_data = {
-            'roles-TOTAL_FORMS': '1',
-            'roles-INITIAL_FORMS': '1',
-            'roles-MIN_NUM_FORMS': '1',
-            'roles-MAX_NUM_FORMS': '1000',
-            'roles-0-name': 'Krab',
-            'roles-0-value': '1',
-            'estimated_total': '10',
-            'form-TOTAL_FORMS': '0',
-            'form-INITIAL_FORMS': '0',
-            'form-MIN_NUM_FORMS': '0',
-            'form-MAX_NUM_FORMS': '1000',
-        }
-
-        response = self.client.post(reverse('allianceauth_pve:new_entry', args=[self.rotation.pk]), form_data)
-
-        self.assertEqual(response.status_code, 200)
-        self.assertTemplateUsed(response, 'allianceauth_pve/entry_form.html')
+        self.assertEqual(len(messages), 1)
+        self.assertEqual(messages[0].message, 'Error: Form not valid, you need at least 1 person to receive loot')
 
     def test_post_valid_new_entry(self):
         self.client.force_login(self.testuser)
@@ -461,7 +491,7 @@ class TestAddEntryView(TestCase):
             'roles-MAX_NUM_FORMS': '1000',
             'roles-0-name': 'Krab',
             'roles-0-value': '1',
-            'estimated_total': '1660200000.0',
+            'estimated_total': '1660200000',
             'form-TOTAL_FORMS': '2',
             'form-INITIAL_FORMS': '0',
             'form-MIN_NUM_FORMS': '0',
@@ -511,7 +541,7 @@ class TestAddEntryView(TestCase):
             'roles-MAX_NUM_FORMS': '1000',
             'roles-0-name': 'Krabs',
             'roles-0-value': '1',
-            'estimated_total': '1660200000.0',
+            'estimated_total': '1660200000',
             'form-TOTAL_FORMS': '2',
             'form-INITIAL_FORMS': '1',
             'form-MIN_NUM_FORMS': '0',
@@ -573,7 +603,7 @@ class TestDeleteEntryView(TestCase):
         cls.entry: Entry = Entry.objects.create(
             rotation=cls.rotation,
             created_by=cls.testuser,
-            estimated_total=1_000_000_000.0
+            estimated_total=1_000_000_000
         )
 
     def test_delete_success(self):
