@@ -1,23 +1,25 @@
 import datetime
+import re
 
 from django.http import JsonResponse
 from django.shortcuts import render, redirect, get_object_or_404
 from django.contrib.auth.decorators import login_required, permission_required
 from django.contrib import messages
-from django.contrib.auth.models import User, Permission
+from django.contrib.auth.models import Permission
 from django.contrib.contenttypes.models import ContentType
 from django.utils import timezone
 from django.core.paginator import Paginator
-from django.db.models import F, Q, Count
+from django.db.models import F, Q, Count, Exists, OuterRef
 from django.db import transaction
 from django.views.generic.detail import DetailView
+from django.conf import settings
 
 from allianceauth.services.hooks import get_extension_logger
 from allianceauth.authentication.models import CharacterOwnership
 
 from .models import Entry, EntryCharacter, Rotation, EntryRole, General
 from .forms import NewEntryForm, NewShareFormSet, NewRotationForm, CloseRotationForm, NewRoleFormSet
-from .actions import running_averages
+from .actions import running_averages, check_forms_valid
 
 logger = get_extension_logger(__name__)
 
@@ -66,7 +68,9 @@ def rotation_view(request, rotation_id):
     r = get_object_or_404(Rotation, pk=rotation_id)
 
     if request.method == 'POST' and not r.is_closed and request.user.has_perm('allianceauth_pve.manage_rotations'):
-        closeform = CloseRotationForm(request.POST)
+        copied_data = request.POST.copy()
+        copied_data['sales_value'] = copied_data['sales_value'].replace(',', '')
+        closeform = CloseRotationForm(copied_data)
 
         if closeform.is_valid():
             with transaction.atomic():
@@ -99,8 +103,7 @@ def rotation_view(request, rotation_id):
 
     context = {
         'rotation': r,
-        'summary_first': summary[:summary_count_half],
-        'summary_second': summary[summary_count_half:],
+        'summaries': [summary[:summary_count_half], summary[summary_count_half:]],
         'entries': entries_paginator.get_page(page),
         'closeform': closeform,
     }
@@ -122,13 +125,20 @@ def get_avaiable_ratters(request, name=None):
     )
 
     if name:
-        ownerships = ownerships.filter(character__character_name__icontains=name)
+        alts_name = CharacterOwnership.objects.filter(user=OuterRef('user'), character__character_name__icontains=name)
+        ownerships = ownerships.filter(
+            Q(character__character_name__icontains=name) |
+            (Exists(alts_name) & Q(character=F('user__profile__main_character')))
+        )
 
     exclude_ids = request.GET.getlist('excludeIds', [])
 
     if len(exclude_ids) > 0:
         ownerships = ownerships.exclude(character_id__in=exclude_ids)
 
+    if getattr(settings, 'PVE_ONLY_MAINS', False):
+        ownerships = ownerships.filter(character=F('user__profile__main_character'))
+
     return JsonResponse({
         'result': [
             {
@@ -162,67 +172,65 @@ def add_entry(request, rotation_id, entry_id=None):
             return redirect('allianceauth_pve:rotation_view', rotation_id)
 
     if request.method == 'POST':
-        entry_form = NewEntryForm(request.POST)
+        copied_data = request.POST.copy()
+
+        copied_data['estimated_total'] = copied_data['estimated_total'].replace(',', '')
+        entry_form = NewEntryForm(copied_data)
         share_form = NewShareFormSet(request.POST)
         role_form = NewRoleFormSet(request.POST, prefix='roles')
 
-        if role_form.is_valid():
-            roles_choices = [(new_role['name'], new_role['name']) for new_role in role_form.cleaned_data if len(new_role) > 0]
-            for form in share_form:
-                form.fields['role'].choices = roles_choices
+        errors = check_forms_valid(role_form, entry_form, share_form)
+        if len(errors) == 0:
+            with transaction.atomic():
+                if entry_id:
+                    entry.ratting_shares.all().delete()
+                    entry.roles.all().delete()
+                    entry.estimated_total = entry_form.cleaned_data['estimated_total']
+                    entry.save()
+                else:
+                    entry = Entry.objects.create(
+                        rotation=rotation,
+                        estimated_total=entry_form.cleaned_data['estimated_total'],
+                        created_by=request.user,
+                    )
 
-            if entry_form.is_valid() and share_form.is_valid():
-                if share_form.total_form_count() > 0 and role_form.total_form_count() > 0:
-                    with transaction.atomic():
-                        if entry_id:
-                            entry.ratting_shares.all().delete()
-                            entry.roles.all().delete()
-                            entry.estimated_total = entry_form.cleaned_data['estimated_total']
-                            entry.save()
-                        else:
-                            entry = Entry.objects.create(
-                                rotation=rotation,
-                                estimated_total=entry_form.cleaned_data['estimated_total'],
-                                created_by=request.user,
-                            )
+                to_add = []
 
-                        to_add = []
+                for new_role in role_form.cleaned_data:
+                    to_add.append(EntryRole(entry=entry, name=new_role['name'], value=new_role['value']))
 
-                        for new_role in role_form.cleaned_data:
-                            to_add.append(EntryRole(entry=entry, name=new_role['name'], value=new_role['value']))
+                EntryRole.objects.bulk_create(to_add)
+                to_add.clear()
 
-                        EntryRole.objects.bulk_create(to_add)
-                        to_add.clear()
+                setups = set()
 
-                        setups = set()
+                for new_share in share_form.cleaned_data:
+                    role = entry.roles.get(name=new_share['role'])
 
-                        for new_share in share_form.cleaned_data:
-                            role = entry.roles.get(name=new_share['role'])
+                    setup = new_share['helped_setup'] and new_share['user'] not in setups
+                    if setup:
+                        setups.add(new_share['user'])
 
-                            setup = new_share['helped_setup'] and new_share['user'] not in setups
-                            if setup:
-                                setups.add(new_share['user'])
+                    to_add.append(EntryCharacter(
+                        entry=entry,
+                        role=role,
+                        user_character_id=new_share['character'],
+                        user_id=new_share['user'],
+                        site_count=new_share['site_count'],
+                        helped_setup=setup,
+                    ))
 
-                            to_add.append(EntryCharacter(
-                                entry=entry,
-                                role=role,
-                                user_character_id=new_share['character'],
-                                user_id=new_share['user'],
-                                site_count=new_share['site_count'],
-                                helped_setup=setup,
-                            ))
+                EntryCharacter.objects.bulk_create(to_add)
 
-                        EntryCharacter.objects.bulk_create(to_add)
+                entry.update_share_totals()
 
-                        entry.update_share_totals()
+            messages.success(request, 'Entry added successfully')
 
-                    messages.success(request, 'Entry added successfully')
+            return redirect('allianceauth_pve:rotation_view', rotation_id)
 
-                    return redirect('allianceauth_pve:rotation_view', rotation_id)
-            else:
-                logger.error(f'forms not valid\nentry: {entry_form.errors}\nshares: {share_form.errors}\nroles: {role_form.errors}')
         else:
-            logger.error(f'forms not valid\nentry: {entry_form.errors}\nshares: {share_form.errors}\nroles: {role_form.errors}')
+            for error in errors:
+                messages.error(request, f'Error: {error}')
 
     else:
         if entry_id:
@@ -259,7 +267,7 @@ def add_entry(request, rotation_id, entry_id=None):
         'shareforms': share_form,
         'roleforms': role_form,
         'rotation': rotation,
-        'rolessetups': rotation.roles_setups.alias(roles_num=Count('roles')).filter(roles_num__gt=0)
+        'rolessetups': rotation.roles_setups.alias(roles_num=Count('roles')).filter(roles_num__gt=0),
     }
 
     return render(request, 'allianceauth_pve/entry_form.html', context=context)
